#!/usr/bin/env python
# coding=utf-8


"""
ASGI Middleware Static File
"""

from .core import (  # noqa: F401
    ASGIMiddlewareStaticFile,
    ASGIMiddlewarePath,
)

__version__ = '0.3.1'

__author__ = 'Rex Zhang'
__author_email__ = 'rex.zhang@gmail.com'
__licence__ = 'MIT'

__description__ = 'ASGI Middleware for serving Static File.'
__project_url__ = 'https://github.com/rexzhang/asgi-middleware-static-file'
